@@ -10,7 +10,7 @@ use Mail::Send;
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.10 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.11 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -133,7 +133,7 @@ Dave Rolsky, <autarch@urth.org>
 =head1 SEE ALSO
 
 
-Log::Dispatch, Log::Dispatch::Email,
+Log::Dispatch, Log::Dispatch::ApacheLog, Log::Dispatch::Email,
 Log::Dispatch::Email::MailSendmail, Log::Dispatch::Email::MIMELite,
 Log::Dispatch::File, Log::Dispatch::Handle, Log::Dispatch::Output,
 Log::Dispatch::Screen, Log::Dispatch::Syslog
