@@ -9,7 +9,7 @@ use fields qw( stderr );
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.10 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.11 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -127,9 +127,9 @@ Dave Rolsky, <autarch@urth.org>
 
 =head1 SEE ALSO
 
-Log::Dispatch, Log::Dispatch::Email, Log::Dispatch::Email::MailSend,
-Log::Dispatch::Email::MailSendmail, Log::Dispatch::Email::MIMELite,
-Log::Dispatch::File, Log::Dispatch::Handle, Log::Dispatch::Output,
-Log::Dispatch::Syslog
+Log::Dispatch, Log::Dispatch::ApacheLog, Log::Dispatch::Email,
+Log::Dispatch::Email::MailSend, Log::Dispatch::Email::MailSendmail,
+Log::Dispatch::Email::MIMELite, Log::Dispatch::File,
+Log::Dispatch::Handle, Log::Dispatch::Output, Log::Dispatch::Syslog
 
 =cut
